// Copyright 2023 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


import SwiftUI

import ArcGIS

struct ContentView: View {

    @State private var map: Map = {
        let map = Map(basemapStyle: .arcGISTopographic)

        map.initialViewpoint = Viewpoint(latitude: 34.02700, longitude: -118.80500, scale: 72_000)

        let featureServiceURL = URL(string: "https://services3.arcgis.com/GVgbJbqm8hXASVYi/arcgis/rest/services/Trailheads/FeatureServer/0")!
        let serviceFeatureTable = ServiceFeatureTable(url: featureServiceURL)
        let trailheadsLayer = FeatureLayer(featureTable: serviceFeatureTable)
        map.addOperationalLayer(trailheadsLayer)

        return map
    }()

    var body: some View {

        MapView(map: map)

    }

}


